@@ -1,4 +1,5 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
+
 """Example of perodic dump of homekit services.
 
 This example is useful when a user wants an ondemand
@@ -6,10 +7,12 @@ list of HomeKit devices on the network.
 
 """
 
+from __future__ import annotations
+
 import argparse
 import asyncio
 import logging
-from typing import Any, Optional, cast
+from typing import Any, cast
 
 from zeroconf import IPVersion, ServiceBrowser, ServiceStateChange, Zeroconf
 from zeroconf.asyncio import AsyncServiceInfo, AsyncZeroconf
@@ -21,7 +24,7 @@ async def async_watch_services(aiozc: AsyncZeroconf) -> None:
     zeroconf = aiozc.zeroconf
     while True:
         await asyncio.sleep(5)
-        infos = []
+        infos: list[AsyncServiceInfo] = []
         for name in zeroconf.cache.names():
             if not name.endswith(HAP_TYPE):
                 continue
@@ -29,35 +32,38 @@ async def async_watch_services(aiozc: AsyncZeroconf) -> None:
         tasks = [info.async_request(aiozc.zeroconf, 3000) for info in infos]
         await asyncio.gather(*tasks)
         for info in infos:
-            print("Info for %s" % (info.name))
+            print(f"Info for {info.name}")
             if info:
-                addresses = ["%s:%d" % (addr, cast(int, info.port)) for addr in info.parsed_addresses()]
-                print("  Addresses: %s" % ", ".join(addresses))
-                print("  Weight: %d, priority: %d" % (info.weight, info.priority))
+                addresses = [f"{addr}:{cast(int, info.port)}" for addr in info.parsed_addresses()]
+                print(f"  Addresses: {', '.join(addresses)}")
+                print(f"  Weight: {info.weight}, priority: {info.priority}")
                 print(f"  Server: {info.server}")
                 if info.properties:
                     print("  Properties are:")
                     for key, value in info.properties.items():
-                        print(f"    {key}: {value}")
+                        print(f"    {key!r}: {value!r}")
                 else:
                     print("  No properties")
             else:
                 print("  No info")
-            print('\n')
+            print("\n")
 
 
 class AsyncRunner:
     def __init__(self, args: Any) -> None:
         self.args = args
-        self.threaded_browser: Optional[ServiceBrowser] = None
-        self.aiozc: Optional[AsyncZeroconf] = None
+        self.threaded_browser: ServiceBrowser | None = None
+        self.aiozc: AsyncZeroconf | None = None
 
     async def async_run(self) -> None:
         self.aiozc = AsyncZeroconf(ip_version=ip_version)
         assert self.aiozc is not None
 
         def on_service_state_change(
-            zeroconf: Zeroconf, service_type: str, state_change: ServiceStateChange, name: str
+            zeroconf: Zeroconf,
+            service_type: str,
+            state_change: ServiceStateChange,
+            name: str,
         ) -> None:
             """Dummy handler."""
 
@@ -73,18 +79,18 @@ class AsyncRunner:
         await self.aiozc.async_close()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
 
     parser = argparse.ArgumentParser()
-    parser.add_argument('--debug', action='store_true')
+    parser.add_argument("--debug", action="store_true")
     version_group = parser.add_mutually_exclusive_group()
-    version_group.add_argument('--v6', action='store_true')
-    version_group.add_argument('--v6-only', action='store_true')
+    version_group.add_argument("--v6", action="store_true")
+    version_group.add_argument("--v6-only", action="store_true")
     args = parser.parse_args()
 
     if args.debug:
-        logging.getLogger('zeroconf').setLevel(logging.DEBUG)
+        logging.getLogger("zeroconf").setLevel(logging.DEBUG)
     if args.v6:
         ip_version = IPVersion.All
     elif args.v6_only:
