@@ -20,8 +20,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
 USA
 """
 
+from __future__ import annotations
+
+from collections.abc import Iterable
 from heapq import heapify, heappop, heappush
-from typing import Dict, Iterable, List, Optional, Set, Tuple, Union, cast
+from typing import Union, cast
 
 from ._dns import (
     DNSAddress,
@@ -38,7 +41,7 @@ from .const import _ONE_SECOND, _TYPE_PTR
 
 _UNIQUE_RECORD_TYPES = (DNSAddress, DNSHinfo, DNSPointer, DNSText, DNSService)
 _UniqueRecordsType = Union[DNSAddress, DNSHinfo, DNSPointer, DNSText, DNSService]
-_DNSRecordCacheType = Dict[str, Dict[DNSRecord, DNSRecord]]
+_DNSRecordCacheType = dict[str, dict[DNSRecord, DNSRecord]]
 _DNSRecord = DNSRecord
 _str = str
 _float = float
@@ -66,8 +69,8 @@ class DNSCache:
 
     def __init__(self) -> None:
         self.cache: _DNSRecordCacheType = {}
-        self._expire_heap: List[Tuple[float, DNSRecord]] = []
-        self._expirations: Dict[DNSRecord, float] = {}
+        self._expire_heap: list[tuple[float, DNSRecord]] = []
+        self._expirations: dict[DNSRecord, float] = {}
         self.service_cache: _DNSRecordCacheType = {}
 
     # Functions prefixed with async_ are NOT threadsafe and must
@@ -86,7 +89,8 @@ class DNSCache:
         # replaces any existing records that are __eq__ to each other which
         # removes the risk that accessing the cache from the wrong
         # direction would return the old incorrect entry.
-        store = self.cache.setdefault(record.key, {})
+        if (store := self.cache.get(record.key)) is None:
+            store = self.cache[record.key] = {}
         new = record not in store and not isinstance(record, DNSNsec)
         store[record] = record
         when = record.created + (record.ttl * 1000)
@@ -97,7 +101,9 @@ class DNSCache:
 
         if isinstance(record, DNSService):
             service_record = record
-            self.service_cache.setdefault(record.server_key, {})[service_record] = service_record
+            if (service_store := self.service_cache.get(service_record.server_key)) is None:
+                service_store = self.service_cache[service_record.server_key] = {}
+            service_store[service_record] = service_record
         return new
 
     def async_add_records(self, entries: Iterable[DNSRecord]) -> bool:
@@ -132,7 +138,7 @@ class DNSCache:
         for entry in entries:
             self._async_remove(entry)
 
-    def async_expire(self, now: _float) -> List[DNSRecord]:
+    def async_expire(self, now: _float) -> list[DNSRecord]:
         """Purge expired entries from the cache.
 
         This function must be run in from event loop.
@@ -142,10 +148,11 @@ class DNSCache:
         if not (expire_heap_len := len(self._expire_heap)):
             return []
 
-        expired: List[DNSRecord] = []
+        expired: list[DNSRecord] = []
         # Find any expired records and add them to the to-delete list
         while self._expire_heap:
-            when, record = self._expire_heap[0]
+            when_record = self._expire_heap[0]
+            when = when_record[0]
             if when > now:
                 break
             heappop(self._expire_heap)
@@ -153,6 +160,7 @@ class DNSCache:
             # with a different expiration time as it will be removed
             # later when it reaches the top of the heap and its
             # expiration time is met.
+            record = when_record[1]
             if self._expirations.get(record) == when:
                 expired.append(record)
 
@@ -177,7 +185,7 @@ class DNSCache:
         self.async_remove_records(expired)
         return expired
 
-    def async_get_unique(self, entry: _UniqueRecordsType) -> Optional[DNSRecord]:
+    def async_get_unique(self, entry: _UniqueRecordsType) -> DNSRecord | None:
         """Gets a unique entry by key.  Will return None if there is no
         matching entry.
 
@@ -189,7 +197,7 @@ class DNSCache:
             return None
         return store.get(entry)
 
-    def async_all_by_details(self, name: _str, type_: _int, class_: _int) -> List[DNSRecord]:
+    def async_all_by_details(self, name: _str, type_: _int, class_: _int) -> list[DNSRecord]:
         """Gets all matching entries by details.
 
         This function is not thread-safe and must be called from
@@ -197,7 +205,7 @@ class DNSCache:
         """
         key = name.lower()
         records = self.cache.get(key)
-        matches: List[DNSRecord] = []
+        matches: list[DNSRecord] = []
         if records is None:
             return matches
         for record in records.values():
@@ -205,7 +213,7 @@ class DNSCache:
                 matches.append(record)
         return matches
 
-    def async_entries_with_name(self, name: str) -> List[DNSRecord]:
+    def async_entries_with_name(self, name: str) -> list[DNSRecord]:
         """Returns a dict of entries whose key matches the name.
 
         This function is not threadsafe and must be called from
@@ -213,7 +221,7 @@ class DNSCache:
         """
         return self.entries_with_name(name)
 
-    def async_entries_with_server(self, name: str) -> List[DNSRecord]:
+    def async_entries_with_server(self, name: str) -> list[DNSRecord]:
         """Returns a dict of entries whose key matches the server.
 
         This function is not threadsafe and must be called from
@@ -225,7 +233,7 @@ class DNSCache:
     # event loop, however they all make copies so they significantly
     # inefficient.
 
-    def get(self, entry: DNSEntry) -> Optional[DNSRecord]:
+    def get(self, entry: DNSEntry) -> DNSRecord | None:
         """Gets an entry by key.  Will return None if there is no
         matching entry."""
         if isinstance(entry, _UNIQUE_RECORD_TYPES):
@@ -235,7 +243,7 @@ class DNSCache:
                 return cached_entry
         return None
 
-    def get_by_details(self, name: str, type_: _int, class_: _int) -> Optional[DNSRecord]:
+    def get_by_details(self, name: str, type_: _int, class_: _int) -> DNSRecord | None:
         """Gets the first matching entry by details. Returns None if no entries match.
 
         Calling this function is not recommended as it will only
@@ -256,7 +264,7 @@ class DNSCache:
                 return cached_entry
         return None
 
-    def get_all_by_details(self, name: str, type_: _int, class_: _int) -> List[DNSRecord]:
+    def get_all_by_details(self, name: str, type_: _int, class_: _int) -> list[DNSRecord]:
         """Gets all matching entries by details."""
         key = name.lower()
         records = self.cache.get(key)
@@ -264,19 +272,19 @@ class DNSCache:
             return []
         return [entry for entry in list(records.values()) if type_ == entry.type and class_ == entry.class_]
 
-    def entries_with_server(self, server: str) -> List[DNSRecord]:
+    def entries_with_server(self, server: str) -> list[DNSRecord]:
         """Returns a list of entries whose server matches the name."""
         if entries := self.service_cache.get(server.lower()):
             return list(entries.values())
         return []
 
-    def entries_with_name(self, name: str) -> List[DNSRecord]:
+    def entries_with_name(self, name: str) -> list[DNSRecord]:
         """Returns a list of entries whose key matches the name."""
         if entries := self.cache.get(name.lower()):
             return list(entries.values())
         return []
 
-    def current_entry_with_name_and_alias(self, name: str, alias: str) -> Optional[DNSRecord]:
+    def current_entry_with_name_and_alias(self, name: str, alias: str) -> DNSRecord | None:
         now = current_time_millis()
         for record in reversed(self.entries_with_name(name)):
             if (
@@ -287,13 +295,13 @@ class DNSCache:
                 return record
         return None
 
-    def names(self) -> List[str]:
+    def names(self) -> list[str]:
         """Return a copy of the list of current cache names."""
         return list(self.cache)
 
     def async_mark_unique_records_older_than_1s_to_expire(
         self,
-        unique_types: Set[Tuple[_str, _int, _int]],
+        unique_types: set[tuple[_str, _int, _int]],
         answers: Iterable[DNSRecord],
         now: _float,
     ) -> None:
@@ -309,7 +317,7 @@ class DNSCache:
                     # Expire in 1s
                     self._async_set_created_ttl(record, now, 1)
 
-    def _async_set_created_ttl(self, record: DNSRecord, now: _float, ttl: _float) -> None:
+    def _async_set_created_ttl(self, record: DNSRecord, now: _float, ttl: _int) -> None:
         """Set the created time and ttl of a record."""
         # It would be better if we made a copy instead of mutating the record
         # in place, but records currently don't have a copy method.
