@@ -1,29 +1,32 @@
-""" Multicast DNS Service Discovery for Python, v0.14-wmcbrine
-    Copyright 2003 Paul Scott-Murphy, 2014 William McBrine
+"""Multicast DNS Service Discovery for Python, v0.14-wmcbrine
+Copyright 2003 Paul Scott-Murphy, 2014 William McBrine
 
-    This module provides a framework for the use of DNS Service Discovery
-    using IP multicast.
+This module provides a framework for the use of DNS Service Discovery
+using IP multicast.
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-    Lesser General Public License for more details.
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
-    USA
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
+USA
 """
 
+from __future__ import annotations
+
 import enum
 import logging
+from collections.abc import Sequence
 from struct import Struct
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING
 
 from .._dns import DNSPointer, DNSQuestion, DNSRecord
 from .._exceptions import NamePartTooLongException
@@ -50,9 +53,9 @@ DNSQuestion_ = DNSQuestion
 DNSRecord_ = DNSRecord
 
 
-PACK_BYTE = Struct('>B').pack
-PACK_SHORT = Struct('>H').pack
-PACK_LONG = Struct('>L').pack
+PACK_BYTE = Struct(">B").pack
+PACK_SHORT = Struct(">H").pack
+PACK_LONG = Struct(">L").pack
 
 SHORT_CACHE_MAX = 128
 
@@ -74,24 +77,23 @@ LOGGING_DEBUG = logging.DEBUG
 
 
 class DNSOutgoing:
-
     """Object representation of an outgoing packet"""
 
     __slots__ = (
-        'flags',
-        'finished',
-        'id',
-        'multicast',
-        'packets_data',
-        'names',
-        'data',
-        'size',
-        'allow_long',
-        'state',
-        'questions',
-        'answers',
-        'authorities',
-        'additionals',
+        "additionals",
+        "allow_long",
+        "answers",
+        "authorities",
+        "data",
+        "finished",
+        "flags",
+        "id",
+        "multicast",
+        "names",
+        "packets_data",
+        "questions",
+        "size",
+        "state",
     )
 
     def __init__(self, flags: int, multicast: bool = True, id_: int = 0) -> None:
@@ -99,20 +101,20 @@ class DNSOutgoing:
         self.finished = False
         self.id = id_
         self.multicast = multicast
-        self.packets_data: List[bytes] = []
+        self.packets_data: list[bytes] = []
 
         # these 3 are per-packet -- see also _reset_for_next_packet()
-        self.names: Dict[str, int] = {}
-        self.data: List[bytes] = []
+        self.names: dict[str, int] = {}
+        self.data: list[bytes] = []
         self.size: int = _DNS_PACKET_HEADER_LEN
         self.allow_long: bool = True
 
         self.state = STATE_INIT
 
-        self.questions: List[DNSQuestion] = []
-        self.answers: List[Tuple[DNSRecord, float]] = []
-        self.authorities: List[DNSPointer] = []
-        self.additionals: List[DNSRecord] = []
+        self.questions: list[DNSQuestion] = []
+        self.answers: list[tuple[DNSRecord, float]] = []
+        self.authorities: list[DNSPointer] = []
+        self.additionals: list[DNSRecord] = []
 
     def is_query(self) -> bool:
         """Returns true if this is a query."""
@@ -129,15 +131,17 @@ class DNSOutgoing:
         self.allow_long = True
 
     def __repr__(self) -> str:
-        return '<DNSOutgoing:{%s}>' % ', '.join(
-            [
-                'multicast=%s' % self.multicast,
-                'flags=%s' % self.flags,
-                'questions=%s' % self.questions,
-                'answers=%s' % self.answers,
-                'authorities=%s' % self.authorities,
-                'additionals=%s' % self.additionals,
-            ]
+        return "<DNSOutgoing:{}>".format(
+            ", ".join(
+                [
+                    f"multicast={self.multicast}",
+                    f"flags={self.flags}",
+                    f"questions={self.questions}",
+                    f"answers={self.answers}",
+                    f"authorities={self.authorities}",
+                    f"additionals={self.additionals}",
+                ]
+            )
         )
 
     def add_question(self, record: DNSQuestion) -> None:
@@ -149,7 +153,7 @@ class DNSOutgoing:
         if not record.suppressed_by(inp):
             self.add_answer_at_time(record, 0.0)
 
-    def add_answer_at_time(self, record: Optional[DNSRecord], now: float_) -> None:
+    def add_answer_at_time(self, record: DNSRecord | None, now: float_) -> None:
         """Adds an answer if it does not expire by a certain time"""
         now_double = now
         if record is not None and (now_double == 0 or not record.is_expired(now_double)):
@@ -219,7 +223,7 @@ class DNSOutgoing:
         self.data.append(self._get_short(value))
         self.size += 2
 
-    def _write_int(self, value: Union[float, int]) -> None:
+    def _write_int(self, value: float | int) -> None:
         """Writes an unsigned integer to the packet"""
         value_as_int = int(value)
         long_bytes = LONG_LOOKUP.get(value_as_int)
@@ -238,7 +242,7 @@ class DNSOutgoing:
 
     def _write_utf(self, s: str_) -> None:
         """Writes a UTF-8 string of a given length to the packet"""
-        utfstr = s.encode('utf-8')
+        utfstr = s.encode("utf-8")
         length = len(utfstr)
         if length > 64:
             raise NamePartTooLongException
@@ -268,7 +272,7 @@ class DNSOutgoing:
         """
 
         # split name into each label
-        if name.endswith('.'):
+        if name and name[-1] == ".":
             name = name[:-1]
 
         index = self.names.get(name, 0)
@@ -277,21 +281,21 @@ class DNSOutgoing:
             return
 
         start_size = self.size
-        labels = name.split('.')
+        labels = name.split(".")
         # Write each new label or a pointer to the existing one in the packet
         self.names[name] = start_size
         self._write_utf(labels[0])
 
         name_length = 0
         for count in range(1, len(labels)):
-            partial_name = '.'.join(labels[count:])
+            partial_name = ".".join(labels[count:])
             index = self.names.get(partial_name, 0)
             if index:
                 self._write_link_to_name(index)
                 return
             if name_length == 0:
-                name_length = len(name.encode('utf-8'))
-            self.names[partial_name] = start_size + name_length - len(partial_name.encode('utf-8'))
+                name_length = len(name.encode("utf-8"))
+            self.names[partial_name] = start_size + name_length - len(partial_name.encode("utf-8"))
             self._write_utf(labels[count])
 
         # this is the end of a name
@@ -312,7 +316,7 @@ class DNSOutgoing:
         self._write_record_class(question)
         return self._check_data_limit_or_rollback(start_data_length, start_size)
 
-    def _write_record_class(self, record: Union[DNSQuestion_, DNSRecord_]) -> None:
+    def _write_record_class(self, record: DNSQuestion_ | DNSRecord_) -> None:
         """Write out the record class including the unique/unicast (QU) bit."""
         class_ = record.class_
         if record.unique is True and self.multicast:
@@ -355,7 +359,11 @@ class DNSOutgoing:
             return True
 
         if LOGGING_IS_ENABLED_FOR(LOGGING_DEBUG):  # pragma: no branch
-            log.debug("Reached data limit (size=%d) > (limit=%d) - rolling back", self.size, len_limit)
+            log.debug(
+                "Reached data limit (size=%d) > (limit=%d) - rolling back",
+                self.size,
+                len_limit,
+            )
         del self.data[start_data_length:]
         self.size = start_size
 
@@ -390,7 +398,11 @@ class DNSOutgoing:
         return records_written
 
     def _has_more_to_add(
-        self, questions_offset: int_, answer_offset: int_, authority_offset: int_, additional_offset: int_
+        self,
+        questions_offset: int_,
+        answer_offset: int_,
+        authority_offset: int_,
+        additional_offset: int_,
     ) -> bool:
         """Check if all questions, answers, authority, and additionals have been written to the packet."""
         return (
@@ -400,7 +412,7 @@ class DNSOutgoing:
             or additional_offset < len(self.additionals)
         )
 
-    def packets(self) -> List[bytes]:
+    def packets(self) -> list[bytes]:
         """Returns a list of bytestrings containing the packets' bytes
 
         No further parts should be added to the packet once this
@@ -481,7 +493,7 @@ class DNSOutgoing:
             else:
                 self._insert_short_at_start(self.id)
 
-            packets_data.append(b''.join(self.data))
+            packets_data.append(b"".join(self.data))
 
             if not made_progress:
                 # Generating an empty packet is not a desirable outcome, but currently
