@@ -1,9 +1,10 @@
 """Unit tests for zeroconf._listener"""
 
+from __future__ import annotations
+
 import logging
 import unittest
 import unittest.mock
-from typing import Tuple, Union
 from unittest.mock import MagicMock, patch
 
 import zeroconf as r
@@ -58,8 +59,9 @@ def test_guard_against_oversized_packets():
 
     try:
         # We are patching to generate an oversized packet
-        with patch.object(outgoing, "_MAX_MSG_ABSOLUTE", 100000), patch.object(
-            outgoing, "_MAX_MSG_TYPICAL", 100000
+        with (
+            patch.object(outgoing, "_MAX_MSG_ABSOLUTE", 100000),
+            patch.object(outgoing, "_MAX_MSG_TYPICAL", 100000),
         ):
             over_sized_packet = generated.packets()[0]
             assert len(over_sized_packet) > const._MAX_MSG_ABSOLUTE
@@ -146,7 +148,7 @@ def test_guard_against_duplicate_packets():
             addr: str,
             port: int,
             transport: _engine._WrappedTransport,
-            v6_flow_scope: Union[Tuple[()], Tuple[int, int]] = (),
+            v6_flow_scope: tuple[()] | tuple[int, int] = (),
         ) -> None:
             """Handle a query or defer it for later processing."""
             super().handle_query_or_defer(msg, addr, port, transport, v6_flow_scope)
